# pylint: disable=W0622
"""cubicweb-celerytest application packaging information"""

modname = 'celery'
distname = 'cubicweb-celery'

numversion = (0, 1, 0)
version = '.'.join(str(num) for num in numversion)

license = 'LGPL'
author = 'Unlish'
author_email = 'contact@unlish.com'
description = 'Celery cube'
#web = 'http://www.cubicweb.org/project/%s' % distname

__depends__ =  {'cubicweb': '>= 3.19.6', 'cwcelery': None}
__recommends__ = {}

classifiers = [
    'Environment :: Web Environment',
    'Framework :: CubicWeb',
    'Programming Language :: Python',
    'Programming Language :: JavaScript',
    ]



from cubicweb_celery import app


@app.cwtask
def newgroup(self, name):
    return self.cw_cnx.create_entity('CWGroup', name=name).eid


@app.cwtask
def newgroup_retried(self, name):
    try:
        1 / 0
    except Exception as ex:
        self.retry(ex, countdown=5)



# copyright 2015 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr -- mailto:contact@logilab.fr
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 2.1 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.


from cubicweb.devtools import testlib
from cubes.cwcelerytest import tasks
from cubicweb_celery import app, init_repo


class DefaultTC(testlib.CubicWebTC):
    def setUp(self):
        super(DefaultTC, self).setUp()
        app.cwrepo = init_repo(app.cwconfig)

    def test_cwtask(self):
        eid = tasks.newgroup(u'test')
        with self.admin_access.repo_cnx() as cnx:
            self.assertEqual(cnx.entity_from_eid(eid).name, u'test')

    def test_default_config(self):
        self.assertTrue(app.conf.CELERY_ENABLE_UTC)
        self.assertEqual('Indian/Maldives',
                         app.conf.CELERY_TIMEZONE)


if __name__ == '__main__':
    from logilab.common.testlib import unittest_main
    unittest_main()
